{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "Assay-specific adjustment of cell barcodes",
            "hints": [
                {
                    "dockerPull": "hubmap/sc-atac-barcode-adj:2.0.3",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/adjust_barcodes.py",
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 0
                    },
                    "id": "#adjust-barcodes.cwl/assay"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#adjust-barcodes.cwl/directory"
                }
            ],
            "id": "#adjust-barcodes.cwl",
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "adj_fastq"
                    },
                    "id": "#adjust-barcodes.cwl/adj_fastq_dir"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "metadata.json"
                    },
                    "id": "#adjust-barcodes.cwl/metadata_json"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#align_reads.cwl",
            "label": "align paired end reads with HISAT2",
            "requirements": [
                {
                    "dockerPull": "hubmap/sc-atac-hisat2-hg38:2.0.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "The first paired end fastq file to be aligned.",
                    "id": "#align_reads.cwl/align_reads/input_fastq1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "doc": "The second paired end fastq file to be aligned.",
                    "id": "#align_reads.cwl/align_reads/input_fastq2"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--processes"
                    },
                    "default": 16,
                    "doc": "The number of threads to use.",
                    "id": "#align_reads.cwl/align_reads/num_threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "alignment.bam"
                    },
                    "id": "#align_reads.cwl/align_reads/paired_end_bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "alignment.bam.bai"
                    },
                    "id": "#align_reads.cwl/align_reads/paired_end_bam_index"
                }
            ],
            "baseCommand": [
                "/opt/align_reads.py"
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Assay-specific adjustment of cell barcodes",
            "requirements": [
                {
                    "dockerPull": "hubmap/sc-atac-seq-hg38:2.0.3",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/convert_to_h5ad.py",
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 6
                    },
                    "default": 500,
                    "id": "#convert_to_h5ad.cwl/bin_size"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#convert_to_h5ad.cwl/cell_by_bin_barcodes"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#convert_to_h5ad.cwl/cell_by_bin_bins"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#convert_to_h5ad.cwl/cell_by_bin_mtx"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#convert_to_h5ad.cwl/cell_by_gene_raw_mtx"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#convert_to_h5ad.cwl/cell_by_gene_smoothed_hdf5"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 0
                    },
                    "id": "#convert_to_h5ad.cwl/umap_coords_csv"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "cell_by_bin.h5ad"
                    },
                    "id": "#convert_to_h5ad.cwl/cell_by_bin_h5ad"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "cell_by_gene.h5ad"
                    },
                    "id": "#convert_to_h5ad.cwl/cell_by_gene_h5ad"
                }
            ],
            "id": "#convert_to_h5ad.cwl",
            "hints": [
                {
                    "class": "LoadListingRequirement",
                    "loadListing": "deep_listing"
                },
                {
                    "class": "NetworkAccess",
                    "networkAccess": true
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#archr_analyze.cwl",
            "label": "ArchR analysis",
            "requirements": [
                {
                    "dockerPull": "hubmap/sc-atac-seq-hg38:2.0.3",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        "$(inputs.bam_file)",
                        "$(inputs.bam_index)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "networkAccess": true,
                    "class": "NetworkAccess"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bam_file",
                        "valueFrom": "$(self.basename)"
                    },
                    "doc": "The sorted BAM file with cell ids in the CB tag.",
                    "id": "#archr_analyze.cwl/archr_analyze/bam_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--bam_index",
                        "valueFrom": "$(self.basename)"
                    },
                    "doc": "The BAM file index.",
                    "id": "#archr_analyze.cwl/archr_analyze/bam_index"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--minCells"
                    },
                    "default": 1000,
                    "doc": "The minimum number of cells in the ArchR project that must pass filtering before a warning message is printed. E.g. 1000",
                    "id": "#archr_analyze.cwl/archr_analyze/minCells"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--minFrags"
                    },
                    "default": 2000,
                    "doc": "The minimum number of mapped ATAC-seq fragments required per cell to pass filtering. E.g. 2000",
                    "id": "#archr_analyze.cwl/archr_analyze/minFrags"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--minTSS"
                    },
                    "default": 1.5,
                    "doc": "The minimum numeric transcription start site (TSS) enrichment score required to pass filtering. E.g. 1.5",
                    "id": "#archr_analyze.cwl/archr_analyze/minTSS"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--threads"
                    },
                    "default": 2,
                    "doc": "Number of threads to use.",
                    "id": "#archr_analyze.cwl/archr_analyze/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "QualityControl/*/*-Fragment_Size_Distribution.pdf"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/Fragment_Size_Distribution_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*/Plots/GeneScores-Marker-Heatmap.pdf"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/GeneScores-Marker-Heatmap_pdf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*/Plots/Peak-Call-Summary.pdf"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/Peak-Call-Summary_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*/Plots/Peak-Marker-Heatmap.pdf"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/Peak-Marker-Heatmap_pdf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*/Plots/Plot-UMAP-Sample-Clusters.pdf"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/Plot-UMAP-Sample-Clusters_pdf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*/Plots/QC-Sample-FragSizes-TSSProfile.pdf"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/QC-Sample-FragSizes-TSSProfile_pdf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*/Plots/QC-Sample-Statistics.pdf"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/QC-Sample-Statistics_pdf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*/Plots/TSS-vs-Frags.pdf"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/TSS-vs-Frags_pdf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "QualityControl/*/*-TSS_by_Unique_Frags.pdf"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/TSS_by_Unique_Frags_pdf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "barcodes.txt"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/cell_by_bin_barcodes"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "bins.txt"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/cell_by_bin_bins"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "cell_by_bin.mtx"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/cell_by_bin_mtx"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "cell_by_gene_raw.mtx"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/cell_by_gene_raw_mtx"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "cell_by_gene_smoothed.hdf5"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/cell_by_gene_smoothed_hdf5"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "cell_column_data.csv"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/cell_column_data_csv"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "gene_markers.csv"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/gene_markers_csv"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "gene_row_data.csv"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/gene_row_data_csv"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "peak_markers.csv"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/peak_markers_csv"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "peaks.bed"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/peaks_bed"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "peaks.csv"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/peaks_csv"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "umap_coords_clusters.csv"
                    },
                    "id": "#archr_analyze.cwl/archr_analyze/umap_coords_clusters_csv"
                }
            ],
            "baseCommand": [
                "Rscript",
                "/opt/run_ArchR_analysis.R"
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/assay"
                },
                {
                    "type": "Directory",
                    "id": "#main/concat_fastq_dir"
                },
                {
                    "type": "File",
                    "id": "#main/input_fastq1"
                },
                {
                    "type": "File",
                    "id": "#main/input_fastq2"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/analyze_with_ArchR/Fragment_Size_Distribution_pdf",
                    "id": "#main/Fragment_Size_Distribution_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/analyze_with_ArchR/GeneScores-Marker-Heatmap_pdf",
                    "id": "#main/GeneScores-Marker-Heatmap_pdf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/analyze_with_ArchR/Peak-Call-Summary_pdf",
                    "id": "#main/Peak-Call-Summary_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/analyze_with_ArchR/Peak-Marker-Heatmap_pdf",
                    "id": "#main/Peak-Marker-Heatmap_pdf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/analyze_with_ArchR/Plot-UMAP-Sample-Clusters_pdf",
                    "id": "#main/Plot-UMAP-Sample-Clusters_pdf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/analyze_with_ArchR/QC-Sample-FragSizes-TSSProfile_pdf",
                    "id": "#main/QC-Sample-FragSizes-TSSProfile_pdf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/analyze_with_ArchR/QC-Sample-Statistics_pdf",
                    "id": "#main/QC-Sample-Statistics_pdf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/analyze_with_ArchR/TSS-vs-Frags_pdf",
                    "id": "#main/TSS-vs-Frags_pdf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/analyze_with_ArchR/TSS_by_Unique_Frags_pdf",
                    "id": "#main/TSS_by_Unique_Frags_pdf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/align_reads/paired_end_bam",
                    "id": "#main/bam_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/align_reads/paired_end_bam_index",
                    "id": "#main/bam_index"
                },
                {
                    "type": "File",
                    "outputSource": "#main/convert_to_h5ad/cell_by_bin_h5ad",
                    "id": "#main/cell_by_bin_h5ad"
                },
                {
                    "type": "File",
                    "outputSource": "#main/convert_to_h5ad/cell_by_gene_h5ad",
                    "id": "#main/cell_by_gene_h5ad"
                },
                {
                    "type": "File",
                    "outputSource": "#main/analyze_with_ArchR/cell_column_data_csv",
                    "id": "#main/cell_column_data_csv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/create_fragment_file/fragment_file",
                    "id": "#main/fragment_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#main/analyze_with_ArchR/gene_markers_csv",
                    "id": "#main/gene_markers_csv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/analyze_with_ArchR/gene_row_data_csv",
                    "id": "#main/gene_row_data_csv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/analyze_with_ArchR/peak_markers_csv",
                    "id": "#main/peak_markers_csv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/analyze_with_ArchR/peaks_bed",
                    "id": "#main/peaks_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#main/analyze_with_ArchR/umap_coords_clusters_csv",
                    "id": "#main/umap_coords_clusters_csv"
                }
            ],
            "steps": [
                {
                    "run": "#adjust-barcodes.cwl",
                    "in": [
                        {
                            "source": "#main/assay",
                            "id": "#main/adjust_barcodes/assay"
                        },
                        {
                            "source": [
                                "#main/concat_fastq_dir"
                            ],
                            "linkMerge": "merge_nested",
                            "id": "#main/adjust_barcodes/directory"
                        }
                    ],
                    "out": [
                        "#main/adjust_barcodes/adj_fastq_dir"
                    ],
                    "id": "#main/adjust_barcodes"
                },
                {
                    "run": "#align_reads.cwl",
                    "in": [
                        {
                            "source": "#main/adjust_barcodes/adj_fastq_dir",
                            "valueFrom": "${\n  return {\"class\": \"File\", \"location\": self.location + \"/barcode_added_R1.fastq\"}\n}\n",
                            "id": "#main/align_reads/input_fastq1"
                        },
                        {
                            "source": "#main/adjust_barcodes/adj_fastq_dir",
                            "valueFrom": "${\n  return {\"class\": \"File\", \"location\": self.location + \"/barcode_added_R2.fastq\"}\n}\n",
                            "id": "#main/align_reads/input_fastq2"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/align_reads/num_threads"
                        }
                    ],
                    "out": [
                        "#main/align_reads/paired_end_bam",
                        "#main/align_reads/paired_end_bam_index"
                    ],
                    "id": "#main/align_reads"
                },
                {
                    "run": "#archr_analyze.cwl",
                    "in": [
                        {
                            "source": "#main/align_reads/paired_end_bam",
                            "id": "#main/analyze_with_ArchR/bam_file"
                        },
                        {
                            "source": "#main/align_reads/paired_end_bam_index",
                            "id": "#main/analyze_with_ArchR/bam_index"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/analyze_with_ArchR/threads"
                        }
                    ],
                    "out": [
                        "#main/analyze_with_ArchR/Fragment_Size_Distribution_pdf",
                        "#main/analyze_with_ArchR/TSS_by_Unique_Frags_pdf",
                        "#main/analyze_with_ArchR/QC-Sample-FragSizes-TSSProfile_pdf",
                        "#main/analyze_with_ArchR/QC-Sample-Statistics_pdf",
                        "#main/analyze_with_ArchR/TSS-vs-Frags_pdf",
                        "#main/analyze_with_ArchR/Peak-Call-Summary_pdf",
                        "#main/analyze_with_ArchR/Plot-UMAP-Sample-Clusters_pdf",
                        "#main/analyze_with_ArchR/GeneScores-Marker-Heatmap_pdf",
                        "#main/analyze_with_ArchR/Peak-Marker-Heatmap_pdf",
                        "#main/analyze_with_ArchR/peaks_csv",
                        "#main/analyze_with_ArchR/peaks_bed",
                        "#main/analyze_with_ArchR/peak_markers_csv",
                        "#main/analyze_with_ArchR/gene_markers_csv",
                        "#main/analyze_with_ArchR/cell_column_data_csv",
                        "#main/analyze_with_ArchR/gene_row_data_csv",
                        "#main/analyze_with_ArchR/umap_coords_clusters_csv",
                        "#main/analyze_with_ArchR/cell_by_gene_raw_mtx",
                        "#main/analyze_with_ArchR/cell_by_gene_smoothed_hdf5",
                        "#main/analyze_with_ArchR/cell_by_bin_mtx",
                        "#main/analyze_with_ArchR/cell_by_bin_barcodes",
                        "#main/analyze_with_ArchR/cell_by_bin_bins"
                    ],
                    "id": "#main/analyze_with_ArchR"
                },
                {
                    "run": "#convert_to_h5ad.cwl",
                    "in": [
                        {
                            "source": "#main/analyze_with_ArchR/cell_by_bin_barcodes",
                            "id": "#main/convert_to_h5ad/cell_by_bin_barcodes"
                        },
                        {
                            "source": "#main/analyze_with_ArchR/cell_by_bin_bins",
                            "id": "#main/convert_to_h5ad/cell_by_bin_bins"
                        },
                        {
                            "source": "#main/analyze_with_ArchR/cell_by_bin_mtx",
                            "id": "#main/convert_to_h5ad/cell_by_bin_mtx"
                        },
                        {
                            "source": "#main/analyze_with_ArchR/cell_by_gene_raw_mtx",
                            "id": "#main/convert_to_h5ad/cell_by_gene_raw_mtx"
                        },
                        {
                            "source": "#main/analyze_with_ArchR/cell_by_gene_smoothed_hdf5",
                            "id": "#main/convert_to_h5ad/cell_by_gene_smoothed_hdf5"
                        },
                        {
                            "source": "#main/analyze_with_ArchR/umap_coords_clusters_csv",
                            "id": "#main/convert_to_h5ad/umap_coords_csv"
                        }
                    ],
                    "out": [
                        "#main/convert_to_h5ad/cell_by_bin_h5ad",
                        "#main/convert_to_h5ad/cell_by_gene_h5ad"
                    ],
                    "id": "#main/convert_to_h5ad"
                },
                {
                    "run": "#create_fragment_file.cwl",
                    "in": [
                        {
                            "source": "#main/align_reads/paired_end_bam",
                            "id": "#main/create_fragment_file/input_bam"
                        }
                    ],
                    "out": [
                        "#main/create_fragment_file/fragment_file"
                    ],
                    "id": "#main/create_fragment_file"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "create fragment file",
            "requirements": [
                {
                    "dockerPull": "hubmap/sc-atac-seq-hg38:2.0.3",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": "/opt/bulk/sort_index_frag.py",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "The bam file to use",
                    "id": "#create_fragment_file.cwl/input_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.sort.bed.gz"
                    },
                    "id": "#create_fragment_file.cwl/fragment_file"
                }
            ],
            "id": "#create_fragment_file.cwl"
        }
    ],
    "cwlVersion": "v1.2"
}
